@@ -1,6 +1,7 @@
 import json
 import re
 import socket
+import time
 from http import HTTPStatus
 from typing import Union
 from urllib.parse import urljoin, urlencode
@@ -413,10 +414,11 @@ class RESTClient(RESTAssertion):
         except requests.exceptions.ConnectionError:
             return False
 
-    def wait_service_start(self, timeout: int = 30) -> bool:
+    def wait_service_start(self, timeout: int = 30, interval: int = 3) -> bool:
         """Waiting for the service start.
 
         :param timeout: in sec.
+        :param interval: in sec.
         :return:
         """
 
@@ -425,10 +427,11 @@ class RESTClient(RESTAssertion):
 
         while not status:
             status = self.is_service_initialized(1)
-            timer += 1
+            timer += interval
 
             if timer > timeout - 2:
                 raise TimeoutError(f'The service was not started within {timeout} seconds.')
+            time.sleep(interval)
         return status
 
 
